@@ -3,9 +3,8 @@ use Moo 2;
 use Filter::signatures;
 use feature 'signatures';
 no warnings 'experimental::signatures';
-use PerlX::Maybe;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 =head1 NAME
 
@@ -30,11 +29,13 @@ has '_settings' => (
     handles => [ 'active_sheet_name' ],
 );
 
+# The worksheets themselves
 has '_sheets' => (
     is => 'lazy',
-    default => sub { {} },
+    default => sub { [] },
 );
 
+# Mapping of names to sheet objects
 has '_worksheets' => (
     is => 'lazy',
     default => sub { {} },
@@ -56,7 +57,7 @@ has 'table_styles' => (
     default => sub { {} },
 );
 
-=head2 C<< get_print_areas() >>
+=head2 C<< ->get_print_areas() >>
 
     my $print_areas = $workbook->get_print_areas();
     # [[ [$start_row, $start_col, $end_row, $end_col], ... ]]
@@ -71,19 +72,52 @@ sub get_print_areas( $self ) {
     [ map { $_->get_print_areas } $self->worksheets ]
 }
 
-# <config:config-item config:name="ActiveTable" config:type="string">Sheet3</config:config-item>
+=head2 C<< ->get_active_sheet() >>
+
+    my $sheet = $workbook->get_active_sheet();
+    if( !$sheet ) {
+        # If there is no defined active worksheet, take the first:
+        ($sheet) = $workbook->worksheets();
+    };
+
+Returns the active worksheet, or if there is no such sheet, returns C<undef>.
+
+=cut
+
 sub get_active_sheet($self) {
-    $self->worksheet( $self->active_sheet_name );
+    if( defined( my $name = $self->active_sheet_name )) {
+        return $self->worksheet( $name );
+    } else {
+        return undef
+    };
 }
 
 sub get_filename( $self ) {
     $self->filename
 }
 
+=head2 C<< ->worksheets() >>
+
+    my @sheets = $workbook->worksheets;
+
+Returns the list of worksheets as L<Spreadsheet::ParseODS::Worksheet>
+objects.
+
+=cut
+
 sub worksheets( $self ) {
     @{ $self->_sheets }
 };
 
+=head2 C<< ->worksheet($name) >>
+
+    my $sheet1 = $workbook->worksheet('Sheet 1');
+
+Returns the worksheet with the given name, or if no such worksheet exists,
+returns C<undef>.
+
+=cut
+
 sub worksheet( $self, $name ) {
     $self->_worksheets->{ $name }
 }
